style property
The ruling style, or null to resolve from an enclosing NotebookScope
(else const NotebookStyle()).
Implementation
final NotebookStyle? style;
The ruling style, or null to resolve from an enclosing NotebookScope
(else const NotebookStyle()).
final NotebookStyle? style;